#!/bin/sh
#simple samba settings
#01micko 111122, 120215
#gpl3 
#130512 1.0 Updates for LH64

APPVERSION="1.0"
APPTITLE="Simple Samba Management $APPVERSION"

head -n2 /etc/samba/smb.conf|grep -q rcrsn51
if [ $? -ne 0 ];then
  Xdialog --title "$APPTITLE"  --ok-label "Continue?" --cancel-label "Quit?" --yesno "It is recommended you \
quit this setup \n as you have a custom smb.conf.\
\nWhat do you want to do?" 0 0
  case $? in 
  0)echo;;
  *)exit;;
  esac
fi

#check for 1 running instance
RUNNING=`ps |grep SMBGUI|grep -v grep`
[ "$RUNNING" != "" ] && echo "already running" && exit 0

#check for custom smb.conf
CUSTOM=`grep '^\[' /etc/samba/smb.conf|wc -l`
if [ "$CUSTOM" -gt "3" ];then
    Xdialog --title "$APPTITLE" --ok-label="Continue" --cancel-label="Quit" --yesno "You have a custom Samba configuration. \nThis tool will overwrite your /etc/samba/smb.conf \nhowever a backup will be made automatically. \nIt is recommended you quit and \nconfigure Samba manually" 0 0 0
    case $? in
    0)echo "continuing" 
    cp -af /etc/samba/smb.conf /etc/samba/smb.conf.old ;;
    *)exit 0 ;;
    esac
fi

[ -f /tmp/smb.conf ] &&  rm -f /tmp/smb.conf

#detect at start id samba is running
SAMBARUNNING1=`pidof smbd|head -c1`
if [ "$SAMBARUNNING1" != "" ];then
    ln -sf /usr/share/icons/on.png /tmp/samba.png
    else
        ln -sf /usr/share/icons/off.png /tmp/samba.png
fi

#switch samba daemon on/off
togglesamba()
{
SAMBARUNNING2=`pidof smbd|head -c1` 
if [ "$SAMBARUNNING2" != "" ];then
    ln -sf /usr/share/icons/off.png /tmp/samba.png
    /etc/init.d/samba stop
    sleep 1
    else
        ln -sf /usr/share/icons/on.png /tmp/samba.png
        echo "This file is a flag to start the Samba server" > /etc/samba-start #130512
        sync
        /etc/init.d/samba start
        [ "$CHKBOX" = 'false' ] && rm -f /etc/samba-start #130512
        sleep 1
        [ "$(pidof smbd|head -c1)" ] && yaf-splash -bg green -timeout 6 -close never -text "Samba is running. You can Use LameSMBxplorer or Windows to connect." & #130512
fi
}
export -f togglesamba

#different default paths depending on install type
. /etc/rc.d/PUPSTATE
MYPATH=`grep -iE 'path' /etc/samba/smb.conf|grep -v 'var'|grep -v 'tmp'|awk '{print $3}'`
DEFPATH="$MYPATH"
if [ ! $MYPATH ];then   
    case $PUPMODE in
    12|13)
#    MYPATH=/mnt/home ;;
    MYPATH=/root/spot/Downloads ;; #130512
    *)
#    MYPATH=/root/my-documents ;;
    MYPATH=/root/spot/Downloads ;; #130512
    esac
fi
SHARENAME=`grep -iE '^\[' /etc/samba/smb.conf|grep -v 'global'|grep -v 'printers'|sed -e 's%\[%%' -e 's%\]%%'`
if [ ! $SHARENAME ];then SHARENAME="Downloads"
fi

CURSERVER=`grep "netbios" /etc/samba/smb.conf|awk '{print $4}'`
#echo $CURSERVER > /tmp/randomservername 
#CURENTRY=/tmp/randomservername
[ ! $CURSERVER ] && CURSERVER="$(hostname)"

WGROUP=`grep "workgroup" /etc/samba/smb.conf|awk '{print $3}'`

STATE="false"
[ -e /etc/samba-start ] && STATE="true"
[ "$PROTO_YES" ]

#generate smb.conf
swapvalues()
{
NETBIOSNAME="netbios name ="
if [[ "$SERVERNAME" = "$CURSERVER" || "$SERVERNAME" = "" ]];then
    SERVERNAME=""
    NETBIOSNAME="BLANK"
fi
#case $CHKBOX in
#true)PROTO="max protocol = smb2" ;;
#false)PROTO="" ;;
#esac
echo "#this is a very simple smb.conf to get you started
#coutesy rcrsn51 and gcmartin
[global]
workgroup = $WGROUP
$NETBIOSNAME $SERVERNAME
server string = %h-Just-Lighthouse64 LAN-NAS Services
dns proxy = no
log file = /var/log/samba/log.%m
max log size = 50
force user = spot
map to guest = Bad Password
use client driver = yes
printing = cups
printcap name = cups
load printers = yes
# Delete the two following lines if you don't want clients to follow symlinks.
follow symlinks = yes  
unix extensions = no

[$SHARENAME]
comment = Just-Lighthouse64 Downloads folder
path = $MYPATH
writable = yes
read only = no
guest ok = yes

[printers]
comment = All Printers
path = /var/spool/cups
guest only = yes
printable = yes
use client driver = yes
" > /tmp/smb.conf
if [ "`grep BLANK /tmp/smb.conf`" != "" ];then
 sed -i 's%BLANK%%' /tmp/smb.conf
fi
}
export -f swapvalues

#config test
testconfig()
{
testparm -s /tmp/smb.conf >/tmp/testparm.log 2>&1
echo $?
if [ "$?" = "0" ];then
    echo ""
    else yaf-splash -bg red -timeout 5 -close never -text "ERROR: your smb.conf is not correct, try again" && exit
fi
echo ""  >> /tmp/testparm.log

SVPATH=`grep "path" /tmp/smb.conf|awk '{print $3}'|head -n1`
[ ! $SVPATH ] && echo "ERROR: SHARED PATH IS MISSING" >> /tmp/testparm.log || echo "Ok" >> /tmp/testparm.log
WORKGROUPSET=`grep "workgroup" /tmp/smb.conf|awk '{print $3}'`
[ ! $WORKGROUPSET ] && echo "ERROR: WORKGROUP IS MISSING" >> /tmp/testparm.log || echo "Ok" >> /tmp/testparm.log
defaulttextviewer /tmp/testparm.log
}
export -f testconfig

#if inetd is installed we can have a SWAT button ...
INETD=`which inetd`
if [ "$INETD" != "" ];then
SWATbtn="   <hbox>
   <text use-markup=\"true\"><label>\"<b>Samba Web Administration Tool</b> and <b>Documentation</b>\"</label></text>
   <button tooltip-text=\"This button opens your web browser. You will be prompted for your Samba username and password. Be careful with SWAT if you are new to Samba\">
    <label>SWAT</label>
    <input file stock=\"gtk-jump-to\"></input>
    <action>exit:swat</action>
   </button>
  </hbox>
  <hseparator></hseparator>"
fi
   
#GUI
export SMBGUI="<window title=\"$APPTITLE\" icon-name=\"samba\" window-position=\"1\">
 <vbox>
  <hbox homogeneous=\"true\">
   <text use-markup=\"true\"><label>\"<b>You can personalize some Samba settings here</b>\"</label></text>
  </hbox> 
  <hbox homogeneous=\"true\">
   <text use-markup=\"true\"><label>\"The default <b>user</b> is: <b>root</b>\"</label></text>
  </hbox> 
  <hbox homogeneous=\"true\">
   <text use-markup=\"true\"><label>\"The default <b>password</b> is: <b>woofwoof</b>\"</label></text>
  </hbox> 
  <hbox homogeneous=\"true\">
   <text use-markup=\"true\"><label>\"You can change this and add users later\"</label></text>
  </hbox>
  <hseparator></hseparator>
  <hbox>
   <pixmap>
    <height>40</height>
    <input file>/usr/share/images/samba.gif</input>
   </pixmap>
   <text width-request=\"8\"><label>\"\"</label></text>
   <text><label>Switch Samba Daemon on or off:  </label></text>
   <button tooltip-text=\"Pressing this button when Green will turn off Samba, when Red will turn off Samba\">
     <variable>ARTWORK</variable>
     <input file>/tmp/samba.png</input>
     <action>togglesamba</action>
     <action type=\"refresh\">ARTWORK</action>
    </button>
  </hbox>
  <hseparator></hseparator>
  <hbox homogeneous=\"true\">
   <text use-markup=\"true\"><label>\"You can change the default server <b>netbios</b> name if you wish.\"</label></text> 
  </hbox> 
  <hbox homogeneous=\"true\">
   <text use-markup=\"true\"><label>\"The default is <b>$(hostname)</b>\"</label></text>
   <entry tooltip-text=\"If $(hostname) is in this entry or it is left blank then your netbios name will be $(hostname) which is your computer's hostname. You can change it to anything you like as long as there are no spaces and chars are alpha/numeric. Dots, dashes and underscores are allowed\">
    <default>$CURSERVER</default>
    <variable>SERVERNAME</variable>
   </entry>
   </hbox>
  <hseparator></hseparator>
  <vbox homogeneous=\"true\">
   <text width-request=\"502\" use-markup=\"true\"><label>\"The current Sharename is <b>$SHARENAME</b>\"</label></text>
   <text width-request=\"502\" use-markup=\"true\"><label>\"The default share path is <b>$DEFPATH</b>\"</label></text>
   <text width-request=\"502\" use-markup=\"true\"><label>\"Change either, or both if you wish.\"</label></text>
  </vbox>
  <hbox>
   <entry tooltip-text=\"$SHARENAME is the default mount point of your server. You can change it to anything you like as long as there are no spaces and chars are alpha/numeric. Dots, dashes and underscores are allowed\">
    <default>$SHARENAME</default>
    <variable>SHARENAME</variable>
   </entry>
   <entry fs-action=\"folder\">
    <variable>MYPATH</variable>
    <default>$MYPATH</default>
   </entry>
   <button tooltip-text=\"Browse for suitable share path\">
    <input file stock=\"gtk-open\"></input>
    <action>fileselect:MYPATH</action>
   </button>
  </hbox>
  <hseparator></hseparator>
  <hbox>
   <text use-markup=\"true\"><label>\"Change the default <b>workgroup</b> name\"</label></text> 
   <entry tooltip-text=\"If you have Microsoft Windows machines on your network you should set the Workgroup to the same name as the Windows Workgroup\">
    <default>$WGROUP</default>
    <variable>WGROUP</variable>
    </entry>
  </hbox>
  <hseparator></hseparator>
  <hbox homogeneous=\"true\">
   <checkbox width-request=\"502\" tooltip-text=\"By default Samba Server is not started at system startup. Enable this to start it with every boot.\">
    <label>Start Samba Server at every boot</label>
    <variable>CHKBOX</variable>
    <default>$STATE</default>
   </checkbox>
  </hbox>
  <hseparator></hseparator>
  $SWATbtn
  <hbox homogeneous=\"true\">
   <button width-request=\"132\" height-request=\"32\" space-expand=\"true\" space-fill=\"true\" tooltip-text=\"Clicking Apply will save the above settings, perform a sanity check and restart Samba. Your settings will be ready for use on your Network\">
    <input file stock=\"gtk-apply\"></input>
    <label> $(gettext ROX-Filer \"Apply\")</label>
    <action>exit:ok</action>
   </button>
   <button width-request=\"132\" height-request=\"32\" space-expand=\"true\" space-fill=\"true\" tooltip-text=\"Click to check your smb.conf file.\">
    <label> Test</label>
    <input file stock=\"gtk-index\"></input>
    <action>swapvalues</action>
    <action>testconfig</action>
   </button>
   <button width-request=\"132\" height-request=\"32\" space-expand=\"true\" space-fill=\"true\" use-stock=\"true\" label=\"gtk-quit\" tooltip-text= \"Selecting Quit will leave your current settings alone and NOT restart Samba\">
    <action>exit:quit</action>
   </button>
  </hbox>
 </vbox>
</window>"
I=$IFS; IFS="" 
    for STATEMENTS in  $(gtkdialog4 --program=SMBGUI); do 
        eval $STATEMENTS 2>/dev/null
    done #
    IFS=$I
case $EXIT in
 ok|OK)
   case $CHKBOX in
     true) echo "This file is a flag to start the Samba server" > /etc/samba-start ;; #130512
     false) rm -f /etc/samba-start ;;
   esac
   [ ! $MYPATH ] && yaf-splash -bg red -timeout 5 -close never -text "ERROR: Aborting, you must enter a share path" && exit 1
   [ ! $WGROUP ] && yaf-splash -bg red -timeout 5 -close never -text "ERROR: Aborting, you must enter a workgroup" && exit 1
   if [ ! -f /tmp/smb.conf ];then  
    swapvalues #in case test was chosen it will exist, if not run swapvalues function
    echo "generating smb.conf"
   else
    echo "using smb.conf generated by the test"
   fi
   cp -af /tmp/smb.conf /etc/samba/ #instate new smb.conf
   testparm -s > /tmp/testparm.log #test for integrity
   case $? in
     0)echo "samba is configured" ;;
     *)yaf-splash -bg red -timeout 20 -close box text "ERROR: Aborting, Something went wrong with the Samba configuration. Check the log at /tmp/testparm.log. Please try again or consult the documentation in /usr/share/help" && exit 1 ;;
   esac
   echo "This file is a flag to start the Samba server" > /etc/samba-start #130512
   sync
   /etc/init.d/samba start
   [ "$CHKBOX" = 'false' ] && rm -f /etc/samba-start
   yaf-splash -bg green -timeout 6 -close never -text "Samba is restarting. You can check the log at /tmp/testparm.log"
   exit 0 
  ;;
 swat) 
   echo "This file is a flag to start the Samba server" > /etc/samba-start #130512
   sync
   /etc/init.d/samba start
   [ "$CHKBOX" = 'false' ] && rm -f /etc/samba-start
   defaultbrowser http://localhost:901 & #130512
   yaf-splash -bg green -timeout 2 -close never -text " Opening Samba Web Administration Tool... "
  ;;
 *) MSGCOLOR=yellow
    [ "$(pidof smbd|head -c1)" ] && SMBDMSG=", Samba Server is running." && MSGCOLOR=green
    yaf-splash -bg $MSGCOLOR -timeout 3 -close never -text " Configuration is unchanged${SMBDMSG} "
    exit 0
 ;;
esac
